@@ -5,6 +5,9 @@ import os
 import yaml
 import sys
 
+# global variables
+# config_file_path = None
+
 def check_file_format(file_path):
     """
     Check if the file is in valid yaml format
@@ -34,7 +37,6 @@ def check_and_ask(config):
             elif isinstance(config[key], dict):
                 check_and_ask(config[key])
 
-
 def parse_config():
     config_files = [
         os.path.join(os.path.expanduser("/opt/robin/config/sd-upload"), "sd-upload-config.yml"),
@@ -54,6 +56,7 @@ def parse_config():
             with open(cfg_file, 'r') as config_file:
                 config = yaml.safe_load(config_file)
                 file = cfg_file
+                used_config_file(cfg_file)
                 # file_path = os.path.abspath(cfg_file)
                 # print(f"Config {cfg_file} found at full path {os.path.abspath(cfg_file)}")
                 break
@@ -75,3 +78,12 @@ def parse_config():
         print(f"Error: Failed to write config file. {e}")
 
     return config
+
+def used_config_file(cfg_file):
+    # do not print it out multiple times
+    if cfg_file == used_config_file.last_cfg_file:
+        return
+    used_config_file.last_cfg_file = cfg_file
+    print(f"Config file found at {cfg_file}")
+used_config_file.last_cfg_file = None
+    
\ No newline at end of file
